@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: warp-tls
 version: 3.2.1
-id: warp-tls-3.2.1-5ef485719cfd6433e0f6293a43096960
-key: warpt_5M9ySLafn6VHcqSUz8fs3Y
+id: warp-tls-3.2.1-997d87dd11b6a7d0ddf72c51738cbc7b
+key: warpt_1lHdIJT6rgtLWAtBjzZmp5
 license: MIT
 maintainer: michael@snoyman.com
 stability: Stable
@@ -23,16 +23,16 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-tls-3.2.1
-hs-libraries: HSwarp-tls-3.2.1-5M9ySLafn6VHcqSUz8fs3Y
+hs-libraries: HSwarp-tls-3.2.1-1lHdIJT6rgtLWAtBjzZmp5
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
-    tls-1.3.4-c1ffd726a31a364e53d7dbf7360c4f21
+    tls-1.3.5-cc53341e73a1ad5e4154c36129b6c569
     wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
-    warp-3.2.4-afffa286f2a73716d3c875d3f70e8c61
+    warp-3.2.6-828a707afef115eb99ae18cc2d425cf2
 haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
 haddock-html: /usr/share/doc/haskell-warp-tls/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
